@@ -2,15 +2,15 @@ use crate::{launchermeta, HOME};
 use std::path::PathBuf;
 
 // macOS can only use a sync file picker
-#[cfg(target_os = "macos")]
-#[allow(clippy::unused_async)] // We need the same function signature on all OSs
+#[cfg(all(target_os = "macos", feature = "gui"))]
+#[allow(clippy::unused_async)]
 /// Use the file picker to pick a file, defaulting to `path`
 pub async fn pick_folder(path: &PathBuf) -> Option<PathBuf> {
     rfd::FileDialog::new().set_directory(path).pick_folder()
 }
 
 // Other OSs can use the async version
-#[cfg(not(target_os = "macos"))]
+#[cfg(all(not(target_os = "macos"), feature = "gui"))]
 /// Use the file picker to pick a file, defaulting to `path`
 pub async fn pick_folder(path: &PathBuf) -> Option<PathBuf> {
     rfd::AsyncFileDialog::new()
@@ -20,6 +20,18 @@ pub async fn pick_folder(path: &PathBuf) -> Option<PathBuf> {
         .map(|handle| handle.path().into())
 }
 
+#[cfg(not(feature = "gui"))]
+#[allow(clippy::unused_async)]
+pub async fn pick_folder(_: &PathBuf) -> Option<PathBuf> {
+    use dialoguer::{theme::ColorfulTheme, Input};
+
+    let input: String = Input::with_theme(&ColorfulTheme::default())
+        .with_prompt("Pick a mod output directory")
+        .interact()
+        .ok()?;
+    Some(input.into())
+}
+
 /// Get a maximum of `count` number of the latest versions of Minecraft from the `version_manifest` provided
 pub fn get_latest_mc_versions(
     count: usize,
@@ -68,7 +80,7 @@ pub fn get_latest_mc_versions(
 /// ```
 pub fn remove_semver_patch(input: &str) -> Result<String, semver::Error> {
     // If the input string contains only one period, it already doesn't have the patch version
-    if input.matches(".").collect::<Vec<_>>().len() == 1 {
+    if input.matches('.').count() == 1 {
         // So directly return the string
         Ok(input.into())
     } else {
